@@ -6,6 +6,7 @@ from base64 import b64encode
 
 from hvac import aws_utils, exceptions, adapters, utils, api
 from hvac.constants.client import DEPRECATED_PROPERTIES, DEFAULT_URL
+from hvac.utils import generate_property_deprecation_message
 
 try:
     import hcl
@@ -433,6 +434,8 @@ class Client(object):
         :type wrap_ttl:
         :return:
         :rtype:
+
+        For calls expecting to hit the renew-self endpoint please use the "renew_self_token" method instead
         """
         params = {
             'increment': increment,
@@ -442,7 +445,25 @@ class Client(object):
             params['token'] = token
             return self._adapter.post('/v1/auth/token/renew', json=params, wrap_ttl=wrap_ttl)
         else:
-            return self._adapter.post('/v1/auth/token/renew-self', json=params, wrap_ttl=wrap_ttl)
+            generate_property_deprecation_message("1.0.0", "renew_token() without token param", "renew_self_token() without token param", "renew_self_token")
+            return self.renew_self_token(increment=increment, wrap_ttl=wrap_ttl)
+
+    def renew_self_token(self, increment=None, wrap_ttl=None):
+        """
+        POST /auth/token/renew-self
+
+        :param increment:
+        :type increment:
+        :param wrap_ttl:
+        :type wrap_ttl:
+        :return:
+        :rtype:
+        """
+        params = {
+            'increment': increment,
+        }
+
+        return self._adapter.post('/v1/auth/token/renew-self', json=params, wrap_ttl=wrap_ttl)
 
     def create_token_role(self, role,
                           allowed_policies=None, disallowed_policies=None,
@@ -1183,22 +1204,29 @@ class Client(object):
                             disallow_reauthentication=False, allow_instance_migration=False, mount_point='aws-ec2'):
         """POST /auth/<mount_point>/role/<role>/tag
 
-        :param role:
-        :type role:
-        :param policies:
-        :type policies:
-        :param max_ttl:
-        :type max_ttl:
-        :param instance_id:
-        :type instance_id:
-        :param disallow_reauthentication:
-        :type disallow_reauthentication:
-        :param allow_instance_migration:
-        :type allow_instance_migration:
-        :param mount_point:
-        :type mount_point:
-        :return:
-        :rtype:
+        :param role: Name of the role.
+        :type role: str
+        :param policies: Policies to be associated with the tag. If set, must be a subset of the role's policies. If
+            set, but set to an empty value, only the 'default' policy will be given to issued tokens.
+        :type policies: list
+        :param max_ttl: The maximum allowed lifetime of tokens issued using this role.
+        :type max_ttl: str
+        :param instance_id: Instance ID for which this tag is intended for. If set, the created tag can only be used by
+            the instance with the given ID.
+        :type instance_id: str
+        :param disallow_reauthentication: If set, only allows a single token to be granted per instance ID. This can be
+            cleared with the auth/aws/identity-whitelist endpoint. Defaults to 'false'. Mutually exclusive with
+            allow_instance_migration.
+        :type disallow_reauthentication: bool
+        :param allow_instance_migration: If set, allows migration of the underlying instance where the client resides.
+            This keys off of pendingTime in the metadata document, so essentially, this disables the client nonce check
+            whenever the instance is migrated to a new host and pendingTime is newer than the previously-remembered
+            time. Use with caution. Defaults to 'false'. Mutually exclusive with disallow_reauthentication.
+        :type allow_instance_migration: bool
+        :param mount_point: The path the associated AWS auth method is configured under.
+        :type mount_point: str
+        :return: The create role tag response.
+        :rtype: dict
         """
         params = {
             'role': role,
@@ -1251,6 +1279,10 @@ class Client(object):
             **kwargs
         )
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.create_or_update_approle,
+    )
     def create_role(self, role_name, mount_point='approle', **kwargs):
         """POST /auth/<mount_point>/role/<role name>
 
@@ -1266,6 +1298,10 @@ class Client(object):
 
         return self._adapter.post('/v1/auth/{0}/role/{1}'.format(mount_point, role_name), json=kwargs)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.delete_role,
+    )
     def delete_role(self, role_name, mount_point='approle'):
         """DELETE /auth/<mount_point>/role/<role name>
 
@@ -1279,6 +1315,10 @@ class Client(object):
 
         return self._adapter.delete('/v1/auth/{0}/role/{1}'.format(mount_point, role_name))
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.list_roles,
+    )
     def list_roles(self, mount_point='approle'):
         """GET /auth/<mount_point>/role
 
@@ -1290,6 +1330,10 @@ class Client(object):
 
         return self._adapter.get('/v1/auth/{0}/role?list=true'.format(mount_point))
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.read_role_id,
+    )
     def get_role_id(self, role_name, mount_point='approle'):
         """GET /auth/<mount_point>/role/<role name>/role-id
 
@@ -1304,6 +1348,10 @@ class Client(object):
         url = '/v1/auth/{0}/role/{1}/role-id'.format(mount_point, role_name)
         return self._adapter.get(url)['data']['role_id']
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.update_role_id,
+    )
     def set_role_id(self, role_name, role_id, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/role-id
 
@@ -1323,6 +1371,10 @@ class Client(object):
         }
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.read_role,
+    )
     def get_role(self, role_name, mount_point='approle'):
         """GET /auth/<mount_point>/role/<role name>
 
@@ -1335,6 +1387,10 @@ class Client(object):
         """
         return self._adapter.get('/v1/auth/{0}/role/{1}'.format(mount_point, role_name))
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.generate_secret_id,
+    )
     def create_role_secret_id(self, role_name, meta=None, cidr_list=None, token_bound_cidrs=None, wrap_ttl=None, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/secret-id
 
@@ -1364,6 +1420,10 @@ class Client(object):
             params['token_bound_cidrs'] = token_bound_cidrs
         return self._adapter.post(url, json=params, wrap_ttl=wrap_ttl)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.read_secret_id,
+    )
     def get_role_secret_id(self, role_name, secret_id, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/secret-id/lookup
 
@@ -1382,6 +1442,10 @@ class Client(object):
         }
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.list_secret_id_accessors,
+    )
     def list_role_secrets(self, role_name, mount_point='approle'):
         """LIST /auth/<mount_point>/role/<role name>/secret-id
 
@@ -1398,6 +1462,10 @@ class Client(object):
         )
         return self._adapter.list(url)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.read_secret_id_accessor,
+    )
     def get_role_secret_id_accessor(self, role_name, secret_id_accessor, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/secret-id-accessor/lookup
 
@@ -1414,6 +1482,10 @@ class Client(object):
         params = {'secret_id_accessor': secret_id_accessor}
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.destroy_secret_id,
+    )
     def delete_role_secret_id(self, role_name, secret_id, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/secret-id/destroy
 
@@ -1432,6 +1504,10 @@ class Client(object):
         }
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.destroy_secret_id_accessor,
+    )
     def delete_role_secret_id_accessor(self, role_name, secret_id_accessor, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/secret-id-accessor/destroy
 
@@ -1450,6 +1526,10 @@ class Client(object):
         }
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.create_custom_secret_id,
+    )
     def create_role_custom_secret_id(self, role_name, secret_id, meta=None, mount_point='approle'):
         """POST /auth/<mount_point>/role/<role name>/custom-secret-id
 
@@ -1472,6 +1552,10 @@ class Client(object):
             params['meta'] = meta
         return self._adapter.post(url, json=params)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.12.0',
+        new_method=api.auth_methods.AppRole.login,
+    )
     def auth_approle(self, role_id, secret_id=None, mount_point='approle', use_token=True):
         """POST /auth/<mount_point>/login
 
